==> haskell-http-date-0.0.11-136-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-2DZCnT6XkiQDDTdRoRzChF
key:                  http-date-0.0.11-2DZCnT6XkiQDDTdRoRzChF
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  9e8d0d8ce3dfe695f2274f46284ce49a
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-2DZCnT6XkiQDDTdRoRzChF
depends:
    array-0.5.4.0 attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd
    base-4.16.4.0 bytestring-0.11.4.0 time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.11-138-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-E2fwJvbT2lF8g6FW0xlnls
key:                  http-date-0.0.11-E2fwJvbT2lF8g6FW0xlnls
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  76d4c9b1012ab885f80f3b9eb4f5b56b
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-E2fwJvbT2lF8g6FW0xlnls
depends:
    array-0.5.4.0 attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    base-4.16.4.0 bytestring-0.11.4.0 time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
